@@ -124,7 +124,7 @@ public class CompressionFilter implements Filter {
 
             if (values.size() > 0) {
                 compressionMimeTypes = values.toArray(
-                        new String[values.size()]);
+                        new String[0]);
             } else {
                 compressionMimeTypes = null;
             }
